# TFGPS01A - UAV GNSS navigation module with RTK capability

[![Kicad - production files generator](https://github.com/ThunderFly-aerospace/TFGPS01/actions/workflows/kicad_outputs.yml/badge.svg)](https://github.com/ThunderFly-aerospace/TFGPS01/actions/workflows/kicad_outputs.yml)  ![Slicing](https://github.com/ThunderFly-aerospace/TFGPS01/workflows/Slicing/badge.svg)

The TFGPS01A module is based on multi-constellation uBlox NEO-9 with integrated high-quality patch antenna. The module is capable of receiving GPS, GLONASS, Galileo and BeiDou navigation signals. It is designed primarily for use on small UAVs. Other uses are not excluded. Module can function as a standalone UART GPS or as a USB GPS receiver.

The module has several features for UAVs. For example, it has a pass-through I2C port, payload interface, integrated beeper and safety LED or integrated connector for external safety switch and safety LED.

<p float="left">
<img src="/doc/img/TFGPS01A_top.jpg" width="45%" />
<img src="/doc/img/TFGPS01A_bottom.jpg" width="45%" />
</p>

TFGPS01 is commercially available from [ThunderFly s.r.o.](https://www.thunderfly.cz/), write an email to info@thunderfly.cz or shop at [Tindie store](https://www.tindie.com/products/21789/).

### Features

  * Compatibile with PX4, Ardupilot and most of common flight stacks
  * RTK capability (with NEO-M8P module)
  * Concurrent reception of 4 GNSS
  * Splitted interface for a Payload
  * CUAV V5/V5+/Nano compatible GPS&SAFETY connector
  * Integrated beeper and safety LED indicator
  * Extremely high noise imunity (IIP3 +8 dBm)
  * Daylight visible indicator LEDs

## Usage

### Caution

The TFGPS01 is high-end and extremely sensitive device. The device must be handled with special care. The antenna ceramics and its silver plating is sensitive to acids contained in sweat, therefore touching on antenna should be avoided as possible.

### Compatible GNSS Reciever modules

TFGPS01 is by default equipted with [uBlox NEO-9](https://www.u-blox.com/en/product/neo-m9n-module) and high quality [Taoglas](https://www.taoglas.com/product/cggp-35-3-a-02-gpsglonass-dual-band-patch-antenna-35353-5mm-2/) patch antenna.

It could also be equipped with [uBlox NEO-8](https://www.u-blox.com/en/product/neo-m8p-series) module, which has benefits in RTK capable GNSS receiver modes.

### High noise imunity

The ThunderFly TFGPS01 GNSS receiver is optimized to work in RF noisy environment. This feature is achieved by use of high-linearity LNA at RF input.
The tradeoff of this optimalization is quite high power usage and lower sensitivity compared to standard receivers used in UAV.   Technically these parameters can be optimized for a specific use case by altering the R27 and R26 resistors.

## Hardware
TFGPS01 is designed as Open-Hardware (GPL v3). All documentation is located in this repository.

### PCB
<p float="left">
<img src="/doc/img/TFGPS01A_top_big.jpg" width="45%" />
<img src="/doc/img/TFGPS01A_bot_big.jpg" width="45%" />
</p>

### Box
To protect against external conditions, we have prepared a 3D printed box. The box is designed in OpenSCAD and it allows customization according to the use of reciemer and for the needs of mounting.

<p align="center">
<img src="doc/img/TFGPS_1.jpg" alt="3D printed box" width="80%" />
</p>


Here are examples of various modifications of the box:

<p float="left">
<img src="doc/img/tfgps01_box.png" alt="Example of UAV connectors TFGPS01 3D printed box" width="45%" />
<img src="doc/img/tfgps01_box_usb.png" alt="Example of USB TFGPS01 3D printed box" width="45%" />
</p>

### Mechanical drawing
> TODO


### Diagram

The TFGPS01 could be connected to the Autopilot and to the Payload at same time. The typical situation is in the following picture, where PPS timepulse signal is used by Payload measuring the pollution by dust. The similar, but a more robust configuration is used in the [TF-ATMON system](https://www.thunderfly.cz/tf-atmon.html).

![Typical connection of TFGPS01 to the autopilot and payload](doc/img/TFGPS01_Payload_connection.jpg)

### Eletronic schema

Full schema is avialible in [PDF](hw/cam/docs/TFGPS01A_schematic.pdf)

![schema](hw/cam/docs/TFGPS01A_schematic.svg)

### LED description
 | LED label | Description |
 |------|------|
 | ON  | Indicates 5V power in module |
 | ARM | Safety LED from autopilot |
 | GEO | Geofence status of uBlox |
 | RTK | RTK status of uBlox |
 | TPL | Timepulse from uBlox |

### Pinout

All connector are JST-GH.

#### GPS&SAFETY

Pinout of GPS&SAFETY connector conforms to the [pixhawk hardware standard](https://github.com/pixhawk/Pixhawk-Standards/blob/master/DS-009%20Pixhawk%20Connector%20Standard.pdf)


| pin | Name | Colour | Description |
|-----|------|-------|------------|
| 1   | Vcc (+5V)  | Red | Power for module |
| 2   | RX         | Black |Out from Autopilot |
| 3   | TX         | Black |Out from TFGPS01A |
| 4   | I2C SCL    | White |I2C1 clock from autopilot; Passtrought to I2C connector |
| 5   | I2C SDA    | Yellow |I2C1 data from autopilot; Passtrought to I2C connector |
| 6   | SAFETY_IN  | Blue | Safety switch IN |
| 7   | SAFETY_LED | Blue |Safety LED signal |
| 8   | VDD (+3v3) | Blue |Power for safety switch and safety LED |
| 9   | BUZZER     | Blue |Signal for beeper |
| 10  | GND        | Black|Ground |

#### I2C AUX

I2C AUX is I2C1 output from the autopilot. No other device is connected to I2C.

|Pin| Name|
|---|-----
|1 	| +5V |
|2 	| SCL |
|3 	| SDA |
|4  | GND |

> Pinout conforms to the [pixhawk standard](https://github.com/pixhawk/Pixhawk-Standards/blob/master/DS-009%20Pixhawk%20Connector%20Standard.pdf)

#### Safety switch connector

|Pin| Name| Description |
|---|-----|-------------|
|1 	| SAFETY_VCC| +3.3V (low current) |
|2 	| SAFETY_LED | |
|3 	| SAFETY_IN ||
|4  | BUZZER ||
|5 	| +5V ||
|6  | GND ||

#### Payload conector

The module is equipped with a connector designed for payload connection; this feature is useful for time-sync and navigation data, time-stamping or geo-fencing.

The connector is labelled as `Payload GPS Interface`.

| pin | Name | Description |
|-----|------|-------------|
| 1   | TIMEPULSE | Time-pulse signal from uBlox GNSS receiver |
| 2   | EXTINT | Interrupt output from uBlox |
| 3   | GEO_STAT | GeoStat output from uBlox |
| 4   | SDA | I2C from uBlox |
| 5   | SCL | I2C from uBlox |
| 6   | RX | Rx of uBlox, parallel to the autopilot via a protective resistor|
| 7   | TX | Tx of uBlox, parallel to the autopilot via a protective resistor|
| 8   | GND | Autopilot GND |

#### USB-C

USB is connected to the uBlox module, used for its configuration and testing. Configuration can be done via [u-center](https://www.u-blox.com/en/product/u-center) suite.

### Parameters

  * Dimensions 50x50x11mm
  * Weight 31g
  * Power consumption 40mA (without beeper in use)
